#
# spec file for package gap-browse
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-browse
Version:        1.8.21
Release:        1.4
Summary:        GAP: ncurses interface and browsing applications
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.math.rwth-aachen.de/homes/Browse/
Source:         https://www.math.rwth-aachen.de/homes/Browse/Browse-%version.tar.bz2
BuildRequires:  gap-devel >= 4.12
BuildRequires:  gap-rpm-devel >= 4.12
BuildRequires:  gmp-devel
BuildRequires:  ncurses5-devel
Requires:       gap-core >= 4.12
Requires:       gap-gapdoc >= 1.6
Suggests:       gap-atlasrep >= 2.0
Suggests:       gap-io >= 2.2

%description
The Browse package provides three levels of functionality

* A GAP interface to the ncurses library.
* A generic function for interactive browsing through two-dimensional
  arrays of data.
* Several applications of the first two, e.g., a method for browsing
  character tables, browsing through the content of some data
  collections, or some games.

%prep
%autosetup -n Browse-%version

%build
./configure "%gapdir"
# Browse must be compiled with ncurses-5 or -w5. Crashes with ncurses-6.
make %{?_smp_mflags} \
	CFLAGS="%optflags -DWIDECHARS $(ncursesw5-config --cflags)" \
	LOPTS="$(ncursesw5-config --libs) -lpanelw"

%install
%gappkg_simple_install
pushd "%buildroot/$moddir/"
rm -Rf Makefile configure src
popd

%files -f %name.files

%changelog
* Sun Jun 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.21
  * Fixed another problem when running the tests in 'tst/tests.tst'
    in the background.
  * Support the package extensions feature of GAP 4.13
* Sun Jan 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.20
  * Added the new application "BrowseWizard".
* Tue Dec 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.19
  * Use `IsKernelExtensionAvailable` and `LoadKernelExtension`
    instead of 'LOAD_DYN'.
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.18
  * Browse does no longer assume that
    'GAPInfo.SystemEnvironment.TERM' is available, in particular
    Browse does not try to set this component.
  * Drop the support for the '.zoo' archive format.
  * Support JSON format for files that belong to database
    attributes, document 'DatabaseAttributeString' and related
    functions.
  * Make Browse more robust when called with bad setting of the
    TERM environment variable, in particular it should now no
    longer crash GAP during initialization.
  * Support columns of orthogonal discriminants (OD) and character
    field degrees (d) in 'Browse' for character tables.
* Wed Aug 29 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.8.8
  * Blocks in demo files can now be separated by lines starting
    with #%% which makes testing demo files easier.
  * Fixed a bug in the 'Browse' method for character tables: The
    shown centralizer orders and power map information were not
    correct when a set of characters or class positions was
    prescribed.
  * Fixed a bug in 'BrowseConwayPolynomials': In the displayed
    polynomials, the exponents of those monomials whose
    coefficient is different from 1 were erroneously increased
    by 1.
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 1.8.7
  * Removed the example application 'BrowseTransitiveGroupsInfo',
    because of changes in the underlying library of transitive
    groups.
  * Added the new application 'BrowseBibliographyGapPackages'.
    (This is experimental, strange *.bib files in package
    distributions may cause error messages.)
  * Added a new application that facilitates demos of GAP code,
    see '?Browse: Utility for GAP Demos' for details.
  * The input code 127 is assumed to denote the backspace key
    also if 'NCurses.keys.BACKSPACE' has a different value, which
    apparently happens for some Mac operating systems; up to now,
    entering backspace had no effect with such systems.
  * 'NCurses.Select' now supports the replay and log features of
    'NCurses.BrowseGeneric'. Note that meanwhile several
    applications call 'NCurses.Select', now we can provide
    examples for them that are processed automatically, and
    debugging is easier.
* Fri Dec  5 2014 jengelh@inai.de
- Update to new upstream release 1.8.6
  * "NCurses.EditFields" now deals with long input strings by
  scrolling horizontally.
  * "BrowseAtlasInfo" now uses the improved setup of AtlasRep 1.6:
  * Symbolic values are now supported in selections that are offered
  by "BrowseUserPreferences", for example "PACKAGE_ERROR" in the
  case of "InfoPackageLoadingLevel".
  * Use the precomputed data for "IsPerfectGroup" etc. also when
  "TransitiveGroupsData.OneTransitiveGroup" is called;
* Wed Jun 18 2014 jengelh@inai.de
- Update to new upstream release 1.8.5
  * Fixed two problems with non-breakable spaces in
  gap-publishednicer.bib.
  * Fixed the handling of the 'version' component of database
  attributes; before the fix, it was possible that an attribute
  was regarded as up-to-date, without checking the version number
  in the data file.
  * Avoid literal Ctrl-M characters to work around a bug in Windows 8.
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 1.8.3
  * The new user preference 'EnableMouseEvents' sets the default
  behavior for the GAP session. Enabling/disabling mouse events is
  now regarded as one global status in the current GAP session, and
  browse applications should not set this status when they are
  entered.
  * Fixed 'BrowseGapMethods', 'BrowsePackageVariables', and
  'BrowseProfile': Up to now, the attempt to show the code of a
  function in a pager ran into an error if the file in question
  is not available
  * Case of unset TERM env variable is now handled
  * Extended 'NCurses.Select', as follows:
  - support mouse events (and to enable/disable mouse events)
  - admit "fit" as the value of the 'size' component,
    meaning the smallest possible window size
  - admit an optional 'align' component,
    meaning the alignment of the window in the terminal
  - admit an attribute number instead of 'true'
    for the optional 'border' component
* Fri May 10 2013 jengelh@inai.de
- Split browse (version 1.8.2) off the gap RPM package
- Add browse-make.diff to correct include paths for build
